pub struct RayonTaskHandle<R, E> { /* private fields */ }Expand description
Handle returned by crate::RayonExecutorService for accepted tasks.
This handle supports blocking Self::get, asynchronous .await, and
best-effort cancellation before a Rayon worker starts the task.
Implementations
Sourceimpl<R, E> RayonTaskHandle<R, E>
impl<R, E> RayonTaskHandle<R, E>
Sourcepub fn get(self) -> TaskResult<R, E>
pub fn get(self) -> TaskResult<R, E>
Waits for the task to finish and returns its final result.
Returns
The final task result reported through the underlying TaskHandle.